@@ -495,7 +495,7 @@ def parse_explain(
                 api_group_real_name = version_splited[0]
 
         if api_group_real_name:
-            api_group_for_resource_api_group = api_group_real_name.upper().replace(".", "_")
+            api_group_for_resource_api_group = api_group_real_name.upper().replace(".", "_").replace("-", "_")
             resource_dict["group"] = api_group_for_resource_api_group
             missing_api_group_in_resource: bool = not hasattr(Resource.ApiGroup, api_group_for_resource_api_group)
 
@@ -596,7 +596,7 @@ def write_and_format_rendered(filepath: str, data: str, user_code: str = "") ->
 
     for op in ("format", "check"):
         run_command(
-            command=shlex.split(f"poetry run ruff {op} {filepath}"),
+            command=shlex.split(f"uv run ruff {op} {filepath}"),
             verify_stderr=False,
             check=False,
         )
