@@ -72,7 +72,7 @@ class Deployment(NamespacedResource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not all([
                 self.selector,
                 self.template,
