@@ -28,7 +28,7 @@ class ServiceMeshMember(NamespacedResource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not all([
                 self.control_plane_ref,
             ]):
@@ -38,3 +38,5 @@ class ServiceMeshMember(NamespacedResource):
             _spec = self.res["spec"]
 
             _spec["controlPlaneRef"] = self.control_plane_ref
+
+    # End of generated code
