@@ -133,7 +133,7 @@ class NodeNetworkConfigurationPolicy(Resource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if self.dns_resolver or self.routes or self.iface:
                 self.res.setdefault("spec", {}).setdefault("desiredState", {})
 
