@@ -40,7 +40,7 @@ class PipelineRun(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.pipelineref:
                 raise MissingRequiredArgumentError(argument="pipelineref")
             self.res["spec"] = {}
