@@ -29,7 +29,7 @@ class ServiceMeshMember(NamespacedResource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not all([
                 self.control_plane_ref,
             ]):
